==> dubbo-2.5.0-sources.jar: com/alibaba/dubbo/remoting/transport/AbstractCodec.java <==
/*
 * Copyright 1999-2011 Alibaba Group.
 *  
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *      http://www.apache.org/licenses/LICENSE-2.0
 *  
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.dubbo.remoting.transport;

import java.io.IOException;
import java.net.InetSocketAddress;

import com.alibaba.dubbo.common.Constants;
import com.alibaba.dubbo.common.URL;
import com.alibaba.dubbo.common.logger.Logger;
import com.alibaba.dubbo.common.logger.LoggerFactory;
import com.alibaba.dubbo.common.serialize.Serialization;
import com.alibaba.dubbo.common.utils.NetUtils;
import com.alibaba.dubbo.remoting.Channel;
import com.alibaba.dubbo.remoting.Codec;

/**
 * AbstractCodec
 * 
 * @author william.liangf
 */
public abstract class AbstractCodec implements Codec {
	
	private static final Logger logger = LoggerFactory.getLogger(AbstractCodec.class);

    protected Serialization getSerialization(Channel channel) {
        return CodecSupport.getSerialization(channel.getUrl());
    }

    protected static void checkPayload(Channel channel, long size) throws IOException {
        int payload = Constants.DEFAULT_PAYLOAD;
        if (channel != null && channel.getUrl() != null) {
            payload = channel.getUrl().getPositiveParameter(Constants.PAYLOAD_KEY, Constants.DEFAULT_PAYLOAD);
        }
        if (size > payload) {
        	IOException e = new IOException("Data length too large: " + size + ", max payload: " + payload + ", channel: " + channel);
        	logger.error(e);
            throw e;
        }
    }

	protected boolean isClientSide(Channel channel) {
		String side = (String) channel.getAttribute(Constants.SIDE_KEY);
		if ("client".equals(side)) {
			return true;
		} else if ("server".equals(side)) {
			return false;
		} else {
			InetSocketAddress address = channel.getRemoteAddress();
			URL url = channel.getUrl();
			boolean client = url.getPort() == address.getPort()
					&& NetUtils.filterLocalHost(url.getIp()).equals(
							NetUtils.filterLocalHost(address.getAddress()
									.getHostAddress()));
			channel.setAttribute(Constants.SIDE_KEY, client ? "client"
					: "server");
			return client;
		}
	}

	protected boolean isServerSide(Channel channel) {
		return !isClientSide(channel);
	}

}

==> dubbo-2.5.3-sources.jar: com/alibaba/dubbo/remoting/transport/AbstractCodec.java <==
/*
 * Copyright 1999-2011 Alibaba Group.
 *  
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *      http://www.apache.org/licenses/LICENSE-2.0
 *  
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.dubbo.remoting.transport;

import java.io.IOException;
import java.net.InetSocketAddress;

import com.alibaba.dubbo.common.Constants;
import com.alibaba.dubbo.common.URL;
import com.alibaba.dubbo.common.logger.Logger;
import com.alibaba.dubbo.common.logger.LoggerFactory;
import com.alibaba.dubbo.common.serialize.Serialization;
import com.alibaba.dubbo.common.utils.NetUtils;
import com.alibaba.dubbo.remoting.Channel;
import com.alibaba.dubbo.remoting.Codec2;

/**
 * AbstractCodec
 * 
 * @author william.liangf
 */
public abstract class AbstractCodec implements Codec2 {
	
	private static final Logger logger = LoggerFactory.getLogger(AbstractCodec.class);

    protected Serialization getSerialization(Channel channel) {
        return CodecSupport.getSerialization(channel.getUrl());
    }

    protected static void checkPayload(Channel channel, long size) throws IOException {
        int payload = Constants.DEFAULT_PAYLOAD;
        if (channel != null && channel.getUrl() != null) {
            payload = channel.getUrl().getParameter(Constants.PAYLOAD_KEY, Constants.DEFAULT_PAYLOAD);
        }
        if (payload > 0 && size > payload) {
        	IOException e = new IOException("Data length too large: " + size + ", max payload: " + payload + ", channel: " + channel);
        	logger.error(e);
            throw e;
        }
    }

	protected boolean isClientSide(Channel channel) {
		String side = (String) channel.getAttribute(Constants.SIDE_KEY);
		if ("client".equals(side)) {
			return true;
		} else if ("server".equals(side)) {
			return false;
		} else {
			InetSocketAddress address = channel.getRemoteAddress();
			URL url = channel.getUrl();
			boolean client = url.getPort() == address.getPort()
					&& NetUtils.filterLocalHost(url.getIp()).equals(
							NetUtils.filterLocalHost(address.getAddress()
									.getHostAddress()));
			channel.setAttribute(Constants.SIDE_KEY, client ? "client"
					: "server");
			return client;
		}
	}

	protected boolean isServerSide(Channel channel) {
		return !isClientSide(channel);
	}

}
